18.8.0 (2018-08-16) — Lino Tera Benutzerhandbuch

# 18.8.0 (2018-08-16)

Bei unserer heutigen Baustellenbesichtigung haben wir theoretisch folgende Punkte abgehakt.

Allgemein:

- Nächster Meilenstein ist, dass auch die DLS und DLP aus TIM (Termine und Anwesenheiten) nach Lino importiert werden und die Kalenderfunktionen erweitert werden. En passant kann dann auch die Fakturierung getestet werden: in Lino Rechnungen machen lassen und schauen, ob sie mit der Wirklichkeit übereinstimmen.

- Wir beginnen bald mit der aktiven Testphase: Ich kann auf Knopfdruck über Nacht neue Versionen aufspielen und alle Daten aus TIM nach Lino importieren. Wir haben uns mündlich auf ein Entwicklerpasswort geeinigt, mit dem DD, LS, GV und HS sich während der Testphase einloggen können. Alle anderen Benutzer werden zwar erstellt, aber können sich nicht anmelden.

- Buchhaltung wird von Vera übernommen : Alle Einkaufsrechnungen und Kontoauszüge werden schon in Lino erfasst. Verkaufsrechnungen werden in 2018 noch mit den beiden TIMs erstellt und ausgedruckt, aber daraufhin die jeweiligen Beträge manuell in Lino erfasst, evtl. in einem eigenen Journal (ähnlich wie OD), pro Serie von Rechnungen wird dort ein einziges Dokument erstellt.

TODO (Luc):

- Professional situation : Liste übersetzen. „Homemaker“ ersetzen durch „Housewife“?

- Doppelte Therapeuten in Auswahlfeld „Benutzer“.

- Kein Standardpasswort für die anderen Benutzer.

- Terminplanung : Wochen-Master (Stundenplan), Monatsplaner (Wo sind Lücken? Ausnahmen regeln), Wochenansicht mit diversen Filtermöglichkeiten, Terminblätter drucken zum Verteilen. Zugewiesene Termine werden nicht angezeigt im Dashboard.

- cal.EntriesByCourse : Übersichtlicher gestalten. Jahr anzeigen im Datum. Im KITZ können mehrere Termine pro Tag stattfinden, an mehreren Tage pro Woche. Im SPZ dagegen kommen manche nur 3x pro Jahr…

- Termin erstellen von Therapie aus: geht nicht.

- Themen sind pro Familie und pro Klient, Notizen nur pro Klient.

- MTI Navigator can be irritating. Possibility to hide certain links & conversions. e.g. Person -> Houshold, Person -> Partner should be hidden for normal users.

TALK

- tariff : bleibt pro Client und pro Household. ClientTariffs umbenennen nach TariffGroups oder so. Der eigentliche Stückpreis („das Produkt“) steht dann in Enrolment.fee. Dazu brauchen wir vielleicht noch eine Tabelle von default fees per ClientTariff.

- Idee (zu besprechen): Von einem neuen Klienten aus könnte man eine Aktion starten, die eine Notiz fürs Erstgespräch erstellt, wobei Lino dann falls nötig automatisch eine Aktivität erstellt.

- Übersetzung ClientStates : Statt „Zustand“ eines Patienten „Stand der Beratung“. Aber wir haben in Lino ein Feld „Zustand“ an vielen Stellen: pro Therapie, pro Patient, pro Einschreibung, pro Anwesenheit. Ich zögere noch, die alle nach „Stand“ umzubenennen.

- Übersetzung cal.EntryType „Kalendereintragsart“ ersetzen durch „Dienstleistungsart“. Problem: das stimmt nicht ganz, denn es werden auch z.B. „Feiertage“ oder „Teamversammlungen“ kommen, die dann eindeutig keine Dienstleistungen sind.

- Dass eine Therapie auch für einen bestimmten Haushalt (nicht Klienten) sein kann, macht die Sache etwas kompliziert. so was wäre mit einer Standardsoftware sicherl nicht machbar.

- Was in TIM unter „Stand der Beratung“ stand, steht in Lino jetzt unter EnrolmentStates:

      01 dauert an
      03 abgeschlossen
      05 automatisch abgeschlossen
      06 Abbruch der Beratung
      09 Weitervermittlung
      12 nur Erstkontakt

- in TIM hatten wir das Feld „Stand der Akte“ pro „Partner“. In Lino werden aus den „Partnern“ aber zwei verschiedene Dinge: „Therapien“ (genauer gesagt „Einschreibungen in einer Therapie“) und „Patienten“ (einmaliger Datensatz pro physischer Person). Folglich gibt es jetzt zwei verschiedene Felder: „Stand der Einschreibung“ und „Stand der Patientenakte“. In beiden Feldern habe ich momentan die Auswahlliste „Stand der Akte“ aus TIM.

- ClientStates: das Feld bleibt pro Patient und pro Haushalt, aber kriegt nach Abschluss der tl2.py-Phase vielleicht neue Werte (Aktiv, Inaktiv)

TODO (Vera)

- Partner, die seit Ende 2017 in TIM erstellt wurden, müssen auch in Lino erstellt werden.

DONE (to verify):

- Notizen und Themen werden jetzt importiert aus TIM.

- Notizen und Themen sind sehr vertraulich (nur für Therapeuten), Termine werden auch vom Sekretariat gesehen.

- Site.languages : auch EN und NL

- Kalendereintragsart war leer. Jetzt sind alle DLA importiert und jede DLS hat eine DLA.

- DLA aus TIM importieren nach cal.EventType (Kalendereintragsart).

- No de GSM, Date naissance, Geschlecht n’ont pas été importés

- birth_date wird jetzt importiert

- Therapie E130280 : nicht Harry sondern Daniel müsste Therapeut sein. Falsch importiert. Lino nahm prioritär den T1 statt des T2.

- Rechnungsempfänger und Krankenkasse importieren : pro Patient, nicht pro Einschreibung.

- Akten E180246 und E180247 fehlen in Lino.

- Notizen sind nur bis November 2017 importiert worden

- Status der importierten Anwesenheiten war immer leer. Status „Verpasst“ heißt „abwesend“ in Lino.

DONE and verified:

- Teilnehmer der Gruppentherapien fehlten noch.

- Das Alter wird bei Kleinkindern auf z.B. „18 Monate“

- Therapeutische Gruppen : Kolonnenlayout

- Kindergruppe 2016 hat keine Therapie in Lino. Kindergruppe 2018 fehlt komplett. „Psychodrama Do 2018“ hat Anwesenheiten pro Teilnehmer in TIM korrekt.

- Fakturationsadresse sichtbar machen in Ansicht Patient und Haushalt.

- Import Fakturationsadresse (Zahler) aus TIM scheint nicht zu funktionieren.

- Klientenkontaktarten : Liste füllen und auch Daten importieren aus TIM (z.B. Krankenkasse)

- nationality ist leer. Es fehlen viele Länder.

- Übersetzung Enrolment = „Teilnahme“ (nicht „Einschreibung“)

- NotesByPatient raus. Auch „Health situation“ und zwei weitere Memofelder.

- Modul humanlinks raus, phones rein.

- „Alte Daten löschen“ in TIM

Außerdem besprochen:

- Es wird eine Serie „virtueller Personen“ geben, z.B. „Kaleido“ : das bedeutet „irgendein Mitarbeiter von Kaleido, der als Vertreter fungiert“. Wer das jeweils genau ist, wird nicht in Lino notiert.

- Raum einer Therapie (eines Termins)? Bleibt.

- Brauchen wir eine weitere Tabelle von „Anfragen“ bzw. „Projekten“? Vorerst nicht.

- Notiz Erstgespräch (Create a note from patient without therapy) : Meine Idee („Von einem neuen Klienten aus könnte man eine Aktion starten, die eine Notiz fürs Erstgespräch erstellt, wobei Lino dann falls nötig automatisch eine Aktivität erstellt“) ist nicht nötig. Stattdessen kommt NotesByPatient komplett raus. Notizen sieht man nur über die jeweilige Therapie.

- Pro Therapie gibt es einen verantwortlichen Therapeuten. Die „Disziplinen“ im KITZ werden als unabhängige Therapien erfasst. Das Erstgespräch bzw. die Testphase gilt ebenfalls als eine eigene Therapie. Der Therapeut dieser Therapie ist zunächst auch Primärbegleiter.